pub struct ParserBuilder { /* private fields */ }
Builder for Parser.

Implementations

If true, the emitted syntax tree will be processed by static optimizations. Defaults to false.

If true, the parser will skip script blocks that lack a hat block. This is typically desirable since free floating blocks are never automatically executed, and thus are typically not needed for translation efforts. Defaults to true.

If true, the emitted syntax tree will be automatically adjusted to support convenient translation into languages with zero-based indexing. For instance, with this enabled, an item X of _ block will emit X-1 as the index rather than X, and similar for other list-based blocks. Defaults to false.

All symbol names in the program will be passed through this function, allowing easy conversion of Snap! names to, e.g., valid C-like identifiers. The default operation performs no conversion.

Builds a new Parser.

Errors

If a required field has not been initialized.